==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "El nom proporcionat és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given web address is not a valid URL" : "L'adreça web proporcionada no és un URL vàlid",
    "The given legal notice address is too long" : "L'adreça d'avís legal proporcionada és massa llarga",
    "The given legal notice address is not a valid URL" : "L'adreça d'avís legal proporcionada no és un URL vàlid",
    "The given privacy policy address is too long" : "L'adreça de política de privadesa és massa llarga",
    "The given privacy policy address is not a valid URL" : "L'adreça de la política de privadesa proporcionada no és un URL vàlid",
    "The given slogan is too long" : "L'eslògan proporcionat és massa llarg",
    "The given color is invalid" : "El color proporcionat no és vàlid",
    "Disable-user-theming should be true or false" : "Disable-user-theming ha de ser «true» o «false»",
    "Saved" : "S'ha desat",
    "Invalid app given" : "S'ha indicat una aplicació no vàlida",
    "Invalid type for setting \"defaultApp\" given" : "S'ha indicat un tipus no vàlid per al paràmetre «defaultApp»",
    "Invalid setting key" : "La clau de paràmetre no és vàlida",
    "The file was uploaded" : "S'ha pujat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer pujat supera la directiva upload_max_filesize del fitxer php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer pujat supera la directiva MAX_FILE_SIZE especificada en el formulari HTML",
    "The file was only partially uploaded" : "El fitxer només s'ha pujat parcialment",
    "No file was uploaded" : "No s'ha pujat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s’ha pogut escriure el fitxer en el disc",
    "A PHP extension stopped the file upload" : "Una extensió del PHP ha aturat la pujada del fitxer",
    "No file uploaded" : "No s'ha pujat cap fitxer",
    "Failed to clean up the old administration theming images folder" : "No s'ha pogut netejar la carpeta antiga d'imatges de temes d'administració",
    "Failed to clean up the old administration image folder" : "No s'ha pogut netejar la carpeta antiga d'imatges d'administració",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja utilitzeu un tema personalitzat. És possible que aquest tema substitueixi els paràmetres de l'aplicació Aparença.",
    "Theming" : "Aparença",
    "Appearance and accessibility" : "Aparença i accessibilitat",
    "PHP Imagick module" : "Mòdul Imagick del PHP",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "El mòdul del PHP «imagick» no està habilitat però l'aplicació Temes sí. Perquè la generació d'icones de lloc funcioni correctament, cal instal·lar i habilitar aquest mòdul.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "El mòdul «imagick» del PHP d'aquesta instància no és compatible amb SVG. Per a millorar la compatibilitat, es recomana instal·lar-lo.",
    "Dark theme with high contrast mode" : "Tema fosc amb mode de contrast alt",
    "Enable dark high contrast mode" : "Habilita el mode fosc de contrast alt",
    "Similar to the high contrast mode, but with dark colours." : "Similar al mode de contrast alt, però amb colors foscos.",
    "Dark theme" : "Tema fosc",
    "Enable dark theme" : "Habilita el tema fosc",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema fosc que alleuja els ulls reduint la lluminositat i la brillantor generals.",
    "System default theme" : "Tema per defecte del sistema",
    "Enable the system default" : "Habilita el tema per defecte del sistema",
    "Using the default system appearance." : "S'està utilitzant l'aparença per defecte del sistema.",
    "Dyslexia font" : "Lletra per a la dislèxia",
    "Enable dyslexia font" : "Habilita la lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és una lletra gratuïta dissenyada per a mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "High contrast mode" : "Mode de contrast alt",
    "Enable high contrast mode" : "Habilita el mode de contrast alt",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mode de contrast alt per a facilitar la navegació. La qualitat visual es reduirà, però s'incrementarà la claredat.",
    "Light theme" : "Tema clar",
    "Enable the default light theme" : "Habilita el tema clar per defecte",
    "The default light appearance." : "Aparença clara per defecte.",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "Adjust the Nextcloud theme" : "Ajusteu el tema del Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Els temes us permeten personalitzar fàcilment l'aspecte de la instància i dels clients compatibles. Serà visible per a tots els usuaris.",
    "Advanced options" : "Paràmetres avançats",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·leu l'extensió del PHP d'ImageMagick compatible amb imatges SVG per a generar automàticament icones de web a partir del logotip i del color pujats.",
    "Name" : "Nom",
    "Web link" : "Enllaç web",
    "a safe home for all your data" : "Un lloc segur per a totes les vostres dades",
    "Slogan" : "Eslògan",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Puja un logotip nou",
    "Background and login image" : "Imatge de fons i d'inici de sessió",
    "Upload new background and login image" : "Puja una imatge de fons i inici de sessió nova",
    "Legal notice link" : "Enllaç a l'avís legal",
    "Privacy policy link" : "Enllaç a la política de privadesa",
    "Header logo" : "Logotip de capçalera",
    "Upload new header logo" : "Puja un logotip de capçalera nou",
    "Favicon" : "Icona de web",
    "Upload new favicon" : "Puja una icona de web nova",
    "User settings" : "Paràmetres de l'usuari",
    "Disable user theming" : "Inhabilita els temes d'usuari",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Tot i que podeu seleccionar i personalitzar la instància, els usuaris poden canviar el fons i els colors. Si voleu forçar la vostra personalització, podeu activar-ho.",
    "Appearance and accessibility settings" : "Paràmetres d'aparença i accessibilitat",
    "Background" : "Fons",
    "Customization has been disabled by your administrator" : "L'administrador ha inhabilitat la personalització",
    "Set a custom background" : "Definiu un fons personalitzat",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En alguns casos, les dreceres de teclat poden interferir amb les eines d'accessibilitat. Per a permetre centrar-vos correctament en la vostra eina, podeu inhabilitar totes les dreceres de teclat aquí. Això també inhabilitarà totes les dreceres disponibles en les aplicacions.",
    "Disable all keyboard shortcuts" : "Inhabilita totes les dreceres de teclat",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accés universal és molt important per a nosaltres. Seguim els estàndards web i comprovem que tot es pugui utilitzar també sense el ratolí i amb programes d'assistència, com ara els lectors de pantalla. Volem complir les {guidelines}Pautes d'accessibilitat del contingut web{linkend} 2.1 a nivell AA i amb el tema de contrast alt fins i tot a nivell AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si trobeu cap problema, no dubteu a informar-ne en el {issuetracker}nostre seguiment de problemes{linkend}. A més, si voleu participar, uniu-vos al {designteam}nostre equip de disseny{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Aplicació seleccionada actualment: {app}, posició {position}/{total}",
    "Move up" : "Mou amunt",
    "Move down" : "Mou avall",
    "Custom background" : "Fons personalitzat",
    "Default background" : "Fons per defecte",
    "Change color" : "Canvia el color",
    "No background" : "Sense fons",
    "Select a background from your files" : "Seleccioneu un fons dels fitxers",
    "Select background" : "Selecciona un fons",
    "No background has been selected" : "No s'ha seleccionat cap fons",
    "Theme selection is enforced" : "Es força la selecció de tema",
    "Navigation bar settings" : "Paràmetres de la barra de navegació",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Podeu configurar l'ordre de les aplicacions en la barra de navegació. La primera entrada serà l'aplicació per defecte, que s'obrirà després d'iniciar la sessió o en fer clic en el logotip.",
    "The default app can not be changed because it was configured by the administrator." : "No es pot canviar l'aplicació per defecte perquè l'ha configurat l'administrador.",
    "The app order was changed, to see it in action you have to reload the page." : "L'ordre de les aplicacions ha canviat. Per a veure els canvis, cal que torneu a carregar la pàgina.",
    "Reset default app order" : "Reinicialitza l'ordre de les aplicacions per defecte",
    "Could not set the app order" : "No s'ha pogut definir l'ordre de les aplicacions",
    "Could not reset the app order" : "No s'ha pogut reinicialitzar l'ordre de les aplicacions",
    "Default app" : "Aplicació per defecte",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'aplicació per defecte és l'aplicació que s'obre després d'iniciar la sessió o quan feu clic en el logotip del menú.",
    "Use custom default app" : "Utilitza una aplicació per defecte personalitzada",
    "Global default app" : "Aplicació per defecte global",
    "Global default apps" : "Aplicacions per defecte globals",
    "Default app priority" : "Prioritat de l'aplicació per defecte",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Si un usuari no té habilitada una aplicació, s'utilitza l'aplicació següent amb una prioritat inferior.",
    "Could not set global default apps" : "No s'han pogut definir les aplicacions per defecte globals",
    "Reset to default" : "Reinicialitza els valors per defecte",
    "Upload" : "Puja",
    "Remove background image" : "Suprimeix la imatge de fons",
    "Select a custom color" : "Selecciona un color personalitzat"
},
"nplurals=2; plural=(n != 1);");

==> php83-nextcloud-28.0.6.tgz: share/nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "El nom proporcionat és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given web address is not a valid URL" : "L'adreça web proporcionada no és un URL vàlid",
    "The given legal notice address is too long" : "L'adreça d'avís legal proporcionada és massa llarga",
    "The given legal notice address is not a valid URL" : "L'adreça d'avís legal proporcionada no és un URL vàlid",
    "The given privacy policy address is too long" : "L'adreça de política de privadesa és massa llarga",
    "The given privacy policy address is not a valid URL" : "L'adreça de la política de privadesa proporcionada no és un URL vàlid",
    "The given slogan is too long" : "L'eslògan proporcionat és massa llarg",
    "The given color is invalid" : "El color proporcionat no és vàlid",
    "Disable-user-theming should be true or false" : "Disable-user-theming ha de ser «true» o «false»",
    "Saved" : "S'ha desat",
    "Invalid app given" : "S'ha indicat una aplicació no vàlida",
    "Invalid type for setting \"defaultApp\" given" : "S'ha indicat un tipus no vàlid per al paràmetre «defaultApp»",
    "Invalid setting key" : "La clau de paràmetre no és vàlida",
    "The file was uploaded" : "S'ha pujat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer pujat supera la directiva upload_max_filesize del fitxer php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer pujat supera la directiva MAX_FILE_SIZE especificada en el formulari HTML",
    "The file was only partially uploaded" : "El fitxer només s'ha pujat parcialment",
    "No file was uploaded" : "No s'ha pujat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s’ha pogut escriure el fitxer en el disc",
    "A PHP extension stopped the file upload" : "Una extensió del PHP ha aturat la pujada del fitxer",
    "No file uploaded" : "No s'ha pujat cap fitxer",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja utilitzeu un tema personalitzat. És possible que aquest tema substitueixi els paràmetres de l'aplicació Aparença.",
    "Theming" : "Aparença",
    "Appearance and accessibility" : "Aparença i accessibilitat",
    "PHP Imagick module" : "Mòdul Imagick del PHP",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "El mòdul del PHP «imagick» no està habilitat però l'aplicació Temes sí. Perquè la generació d'icones de lloc funcioni correctament, cal instal·lar i habilitar aquest mòdul.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "El mòdul «imagick» del PHP d'aquesta instància no és compatible amb SVG. Per a millorar la compatibilitat, es recomana instal·lar-lo.",
    "Dark theme with high contrast mode" : "Tema fosc amb mode de contrast alt",
    "Enable dark high contrast mode" : "Habilita el mode fosc de contrast alt",
    "Similar to the high contrast mode, but with dark colours." : "Similar al mode de contrast alt, però amb colors foscos.",
    "Dark theme" : "Tema fosc",
    "Enable dark theme" : "Habilita el tema fosc",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema fosc que alleuja els ulls reduint la lluminositat i la brillantor generals.",
    "System default theme" : "Tema per defecte del sistema",
    "Enable the system default" : "Habilita el tema per defecte del sistema",
    "Using the default system appearance." : "S'està utilitzant l'aparença per defecte del sistema.",
    "Dyslexia font" : "Lletra per a la dislèxia",
    "Enable dyslexia font" : "Habilita la lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és una lletra gratuïta dissenyada per a mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "High contrast mode" : "Mode de contrast alt",
    "Enable high contrast mode" : "Habilita el mode de contrast alt",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mode de contrast alt per a facilitar la navegació. La qualitat visual es reduirà, però s'incrementarà la claredat.",
    "Light theme" : "Tema clar",
    "Enable the default light theme" : "Habilita el tema clar per defecte",
    "The default light appearance." : "Aparença clara per defecte.",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "Adjust the Nextcloud theme" : "Ajusteu el tema del Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Els temes us permeten personalitzar fàcilment l'aspecte de la instància i dels clients compatibles. Serà visible per a tots els usuaris.",
    "Advanced options" : "Paràmetres avançats",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·leu l'extensió del PHP d'ImageMagick compatible amb imatges SVG per a generar automàticament icones de web a partir del logotip i del color pujats.",
    "Name" : "Nom",
    "Web link" : "Enllaç web",
    "a safe home for all your data" : "Un lloc segur per a totes les vostres dades",
    "Slogan" : "Eslògan",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Puja un logotip nou",
    "Background and login image" : "Imatge de fons i d'inici de sessió",
    "Upload new background and login image" : "Puja una imatge de fons i inici de sessió nova",
    "Legal notice link" : "Enllaç a l'avís legal",
    "Privacy policy link" : "Enllaç a la política de privadesa",
    "Header logo" : "Logotip de capçalera",
    "Upload new header logo" : "Puja un logotip de capçalera nou",
    "Favicon" : "Icona de web",
    "Upload new favicon" : "Puja una icona de web nova",
    "User settings" : "Paràmetres de l'usuari",
    "Disable user theming" : "Inhabilita els temes d'usuari",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Tot i que podeu seleccionar i personalitzar la instància, els usuaris poden canviar el fons i els colors. Si voleu forçar la vostra personalització, podeu activar-ho.",
    "Appearance and accessibility settings" : "Paràmetres d'aparença i accessibilitat",
    "Background and color" : "Fons i color",
    "Customization has been disabled by your administrator" : "L'administrador ha inhabilitat la personalització",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color. The primary color will automatically be adapted based on this and used for elements like folder icons, primary buttons and highlights." : "Podeu establir el fons en una imatge del conjunt per defecte, una imatge personalitzada que pugeu o un color llis. El color principal s'adaptarà automàticament en funció d'això i s'utilitzarà per a elements com les icones de les carpetes, els botons principals i els elements destacats.",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En alguns casos, les dreceres de teclat poden interferir amb les eines d'accessibilitat. Per a permetre centrar-vos correctament en la vostra eina, podeu inhabilitar totes les dreceres de teclat aquí. Això també inhabilitarà totes les dreceres disponibles en les aplicacions.",
    "Disable all keyboard shortcuts" : "Inhabilita totes les dreceres de teclat",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accés universal és molt important per a nosaltres. Seguim els estàndards web i comprovem que tot es pugui utilitzar també sense el ratolí i amb programes d'assistència, com ara els lectors de pantalla. Volem complir les {guidelines}Pautes d'accessibilitat del contingut web{linkend} 2.1 a nivell AA i amb el tema de contrast alt fins i tot a nivell AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si trobeu cap problema, no dubteu a informar-ne en el {issuetracker}nostre seguiment de problemes{linkend}. A més, si voleu participar, uniu-vos al {designteam}nostre equip de disseny{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Aplicació seleccionada actualment: {app}, posició {position}/{total}",
    "Move up" : "Mou amunt",
    "Move down" : "Mou avall",
    "Custom background" : "Fons personalitzat",
    "Default background" : "Fons per defecte",
    "Change color" : "Canvia el color",
    "No background" : "Sense fons",
    "Select a background from your files" : "Seleccioneu un fons dels fitxers",
    "Select background" : "Selecciona un fons",
    "No background has been selected" : "No s'ha seleccionat cap fons",
    "Theme selection is enforced" : "Es força la selecció de tema",
    "Navigation bar settings" : "Paràmetres de la barra de navegació",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Podeu configurar l'ordre de les aplicacions en la barra de navegació. La primera entrada serà l'aplicació per defecte, que s'obrirà després d'iniciar la sessió o en fer clic en el logotip.",
    "The default app can not be changed because it was configured by the administrator." : "No es pot canviar l'aplicació per defecte perquè l'ha configurat l'administrador.",
    "The app order was changed, to see it in action you have to reload the page." : "L'ordre de les aplicacions ha canviat. Per a veure els canvis, cal que torneu a carregar la pàgina.",
    "Reset default app order" : "Reinicialitza l'ordre de les aplicacions per defecte",
    "Could not set the app order" : "No s'ha pogut definir l'ordre de les aplicacions",
    "Could not reset the app order" : "No s'ha pogut reinicialitzar l'ordre de les aplicacions",
    "Default app" : "Aplicació per defecte",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'aplicació per defecte és l'aplicació que s'obre després d'iniciar la sessió o quan feu clic en el logotip del menú.",
    "Use custom default app" : "Utilitza una aplicació per defecte personalitzada",
    "Global default app" : "Aplicació per defecte global",
    "Global default apps" : "Aplicacions per defecte globals",
    "Default app priority" : "Prioritat de l'aplicació per defecte",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Si un usuari no té habilitada una aplicació, s'utilitza l'aplicació següent amb una prioritat inferior.",
    "Could not set global default apps" : "No s'han pogut definir les aplicacions per defecte globals",
    "Reset to default" : "Reinicialitza els valors per defecte",
    "Upload" : "Puja",
    "Remove background image" : "Suprimeix la imatge de fons",
    "Background" : "Fons",
    "Set a custom background" : "Definiu un fons personalitzat",
    "Select a custom color" : "Selecciona un color personalitzat"
},
"nplurals=2; plural=(n != 1);");
